\version "2.24.1"

#(define (articulationEvent event articulation property)
  (set! (ly:music-property event property)
        (append
          (ly:music-property event property)
          `(,(make-music 'ArticulationEvent 'articulation-type articulation)))))

% Example \addArticulation staccato { r4 a b c }
addArticulation =
#(define-music-function (articulation music) (symbol? ly:music?)
   (map-some-music
     (lambda (m)
       (case (ly:music-property m 'name)
         ((NoteEvent)  (articulationEvent m articulation 'articulations) m)
         ((EventChord) (articulationEvent m articulation 'elements)      m)
         ((GraceMusic) m)
         (else #f)))
     music))

#(define (tremoloEvent event duration property)
  (set! (ly:music-property event property)
        (append
          (ly:music-property event property)
          `(,(make-music 'TremoloEvent 'tremolo-type duration)))))

addTremolo =
#(define-music-function (d music) (integer? ly:music?)
   (map-some-music
     (lambda (m)
       (case (ly:music-property m 'name)
         ((NoteEvent)  (tremoloEvent m d 'articulations) m)
         ((EventChord) (tremoloEvent m d 'elements)      m)
         (else #f)))
     music))

#(define sharptrill
  #{
    \markup \override #'(baseline-skip . 2.5) \halign #-0.5 \center-column { \tiny \sharp \musicglyph #"scripts.trill" }
  #}
)

#(define naturaltrill
  #{
    \markup \override #'(baseline-skip . 2.5) \halign #-0.5 \center-column { \tiny \natural \musicglyph #"scripts.trill" }
  #}
)

#(define slashturnsharp
  #{
    \markup \override #'(baseline-skip . 2.5) \halign #-0.5 \center-column { \musicglyph #"scripts.slashturn" \tiny \sharp }
  #})

#(define slashturnflat
  #{
    \markup \override #'(baseline-skip . 2.5) \halign #-0.5 \center-column { \musicglyph #"scripts.slashturn" \tiny \flat }
  #})

#(define slashturnnatural
  #{
    \markup \override #'(baseline-skip . 2.5) \halign #-0.5 \center-column { \musicglyph #"scripts.slashturn" \tiny \natural }
  #})

#(define flatslashturn
  #{
    \markup \override #'(baseline-skip . 1.5) \halign #-0.5 \center-column { \tiny \flat \musicglyph #"scripts.slashturn" }
  #})

#(define turnsharp
  #{
    \markup \override #'(baseline-skip . 1.5) \halign #-0.5 \center-column { \musicglyph #"scripts.turn" \tiny \sharp }
  #})

#(define turnnatural
  #{
    \markup \override #'(baseline-skip . 1.5) \halign #-0.5 \center-column { \musicglyph #"scripts.turn" \tiny \natural }
  #})

#(define (tweakarticulation change)
   (let* ((name         (car change))
          (newvalue     (cdr change))
          (articulation (assoc-ref default-script-alist name)))
     (if articulation
       (begin
         (set! articulation (assoc-remove! articulation (car newvalue)))
         (set! articulation (assoc-set! articulation (car newvalue) (cdr newvalue)))
         (set! default-script-alist  (assoc-set! default-script-alist name articulation)))
       (ly:warning "unknown articulation ~a" name))))

#(begin
  (for-each tweakarticulation
    (list '(staccatissimo . (toward-stem-shift . 0.0))
          '(staccatissimo . (avoid-slur . around))
          '(haydnturn . (avoid-slur . around))
          '(slashturn . (avoid-slur . around)))))

ficta = {
  \once \set suggestAccidentals = ##t
  % print second & subsequent accidentals in a bar
  \once \accidentalStyle "dodecaphonic"
}

appoggiaturaUp = #(define-music-function (m) (ly:music?)
  #{
    \appoggiatura {
      \temporary \override Voice.Stem.direction=#UP
      \temporary \override Voice.Slur.direction=#DOWN
      #m
      \revert Voice.Stem.direction
      \revert Voice.Slur.direction
    }
  #}
)

appoggiaturaDown = #(define-music-function (m) (ly:music?)
  #{
    \appoggiatura {
      \temporary \override Voice.Stem.direction=#DOWN
      \temporary \override Voice.Slur.direction=#UP
      #m
      \revert Voice.Stem.direction
      \revert Voice.Slur.direction
    }
  #}
)

acciaccaturaUp = #(define-music-function (m) (ly:music?)
  #{
    \acciaccatura {
      \temporary \override Voice.Stem.direction=#UP
      \temporary \override Voice.Slur.direction=#DOWN
      #m
      \revert Voice.Stem.direction
      \revert Voice.Slur.direction
    }
  #}
)

acciaccaturaDown = #(define-music-function (m) (ly:music?)
  #{
    \acciaccatura {
      \temporary \override Voice.Stem.direction=#DOWN
      \temporary \override Voice.Slur.direction=#UP
      #m
      \revert Voice.Stem.direction
      \revert Voice.Slur.direction
    }
  #}
)

pizz = \markup \whiteout "pizz."
arco = \markup \whiteout "arco"
legno = \markup \whiteout \italic "col legno"
dolce = \markup \whiteout \italic "dolce"
stacc = \markup \whiteout \italic "staccato"
ten = \markup \whiteout \italic "tenuto"
simile = \markup \whiteout \italic "simile"
perdendosi = \markup \whiteout \italic "perdendosi"
mute = \markup \whiteout "con sordini"
nomute = \markup \whiteout "senza sordini"
Solo = \markup \whiteout \bold "Solo"
Soli = \markup \whiteout \bold "Soli"
Tutti = \markup \whiteout \bold "Tutti"
